@@ -20,8 +20,8 @@
 char * Perl_scan_version(pTHX_ char *s, SV *rv);
 SV * Perl_new_version(pTHX_ SV *ver);
 SV * Perl_upg_version(pTHX_ SV *sv);
-SV * Perl_vnumify(pTHX_ SV *sv, SV *vs);
-SV * Perl_vstringify(pTHX_ SV *sv, SV *vs);
+SV * Perl_vnumify(pTHX_ SV *vs);
+SV * Perl_vstringify(pTHX_ SV *vs);
 int Perl_vcmp(pTHX_ SV *lsv, SV *rsv);
 
 #define new_version        Perl_new_version
